/*
 * conf.h - compilation options for slurp
 *
 * Copyright (C) 1992/93/94/95 Stephen Hebditch <steveh@tqmcomms.co.uk>.
 * All rights reserved. TQM Communications, BCM Box 225, London, WC1N 3XX.
 *
 * See README for more information and disclaimers
 *
 * $Id: conf.h,v 1.10 1995/02/07 14:28:34 root Exp root $
 *
 * $Log: conf.h,v $
 * Revision 1.10  1995/02/07  14:28:34  root
 * Improved descriptions of database format and space checking.
 *
 * Revision 1.9  1995/01/10  12:50:42  root
 * Replaced TIMFILE with HOSTFILE.
 * Replaced INDIR and RNEWS with OUTPUT.
 * Redefined SPEEDUP and MAXCACHE.
 * Added GDBM, NOUNISTD and HASHTBLSIZE.
 * Removed SYSV, SYS_ERRLIST and FAKESYSLOG.
 *
 * Revision 1.8  1993/08/20  10:36:02  root
 * Removed SIGRET definition as unused.
 *
 * Revision 1.7  1993/06/23  10:22:38  root
 * Removed NOBUFFOUT option.
 * Amended description for DBM, NDBM and DBZ as can now have none
 * defined if don't want to do history lookups.
 * Amended RNEWS description to describe how to send batches via UUCP.
 * Upped MAXCACHE value and improved description.
 *
 * Revision 1.6  1993/04/22  18:28:01  root
 * Added new compilation options for NOBUFFOUT and UNISTD.
 *
 * Revision 1.5  1993/03/01  17:41:09  root
 * Changed USG definition to SYSV, now used solely in slurp.h.
 * Added explanation of defines for space.c.
 *
 * Revision 1.4  1993/02/14  14:36:16  root
 * Removed BATCHARTSMAX, MSGIDMAX.
 * Added INDIR, BATCHNAME.
 * Modified TIMFILE, RNEWS.
 *
 * Revision 1.0  1992/10/29
 * Initial coding.
 */


/* SLURP CONFIGURATION
   =================== */

/* Set these to the location of the slurp configuration files - NEWSLIB
   is usually a good place for them. The hostname will be added to the
   end of HOSTFILE or, on systems with short filenames, you can specify
   the extension on the command line. */

#define SYSFILE			"/usr/lib/news/slurp.sys"
#define HOSTFILE		"/usr/lib/news/slurp."


/* Speedup sets the number of extra ARTICLE requests that are stacked
   up at the NNTP server awaiting transmission - aka pipelining.
   Although not strictly conforming to the standard this allows a much
   greater article throughput. If you don't want this, set it to zero. */

#define SPEEDUP			7


/* If defined then the number of characters per second transferred
   during the article request phase will be logged. */

#define SPEEDSTATS


/* If defined, MAXCACHE sets the maximum number of articles that may be
   requested in any one session. If this value is exceeded then this is
   noted in the log and the remaining message ids are written to the
   hostfile for later retrieval. If it is undefined then no limit will
   be imposed. */

/*#define MAXCACHE		8192 /* */


/* NEWS CONFIGURATION
   ================== */

/* The location of the news history file, if present. */

#define HISTORY_FILE    "/usr/lib/news/history"


/* The database format used by the news history file. For modern C News
   and INN this will almost certainly be DBZ. The appropriate header
   file and library for the format chosen must be specified in the
   Makefile. If none of the following are defined then history lookups
   will not take place. History lookups can also be disabled with the
   -h command line switch. */

#define DBZ
#undef DBM
#undef GDBM
#undef NDBM


/* The place where by default incoming batches will be placed or, if
   OUTPUT starts with a '|', the filename of a command through which
   batches are to be piped. OUTPUT is usually /usr/spool/news/in.coming
   for C News. Under INN you can either have the batches places in the
   rnews incoming directory or can pipe them straight into rnews
   itself, although this will usually be slower. */

#define OUTPUT			"/var/spool/news/in.coming" /* */
/* #define OUTPUT		"|/usr/bin/rnews" /* */


/* The optimum size of a news batch. Normally this can be left at
   300000L. If you are using INN and have OUTPUT set to rnews, then set
   BATCHSIZEMAX to 0 so the pipe to rnews (and the socket to innd) is
   kept open throughout the session. */

#define BATCHSIZEMAX	300000L


/* The location of the spool directory holding news articles. This is
   needed so we can check if there is enough space before starting to
   build up another batch of articles. */

#define SPOOLDIR        "/var/spool/news"


/* If less then MINFREE blocks are available on the disk containing
   SPOOLDIR or less than MINFILES inodes are available then slurp will
   be aborted. If MINFREE is not defined then a space check is not
   carried out. */

#define MINFREE 4000
/* #define MINFILES 1000 /* */
                        

/* UNIX VERSION CONFIGURATION
   ========================== */

/* Define if your system is missing the <unistd.h> header - e.g. NeXT. */

#undef NOUNISTD


/* Slurp needs to determine how much free disk space there is on the
   file system containing your news spool so it can stop collecting if
   it runs out of space. Which method to use will depend on your
   system. space.c understands defines for SVR4, SVR3, sun, hpux, pyr,
   hp300, __NeXT__, linux, apollo, _AIX, ultrix, __bsdi__,
   __FreeBSD__ and __NetBSD__. For other systems you may need to amend
   space.c or choose not to carry out space checking by leaving MINFREE
   undefined. If the required define is not supplied by the compiler
   (e.g. SVR4, SVR3) then you will need to include it yourself here. */

#define SVR4


/* The facility name which syslog reports errors and stats under. If
   you don't want to use syslog for reporting then undefine and the
   information will be written to stderr instead. */

#define SYSLOG			LOG_NEWS


/* If you don't have syslog then you can use the supplied fakesyslog
   instead. Define FAKESYSLOG to be the name of the file to contain the
   log. */

/* #define FAKESYSLOG      "/usr/lib/news/nntplog" /* */


/* STUFF BELOW PROBABLY DOESN'T NEED ALTERING
   ========================================== */

#define COPYSIZE		16384	/* Articles bigger than this size will
                                   be written to a temporary file while
                                   they are being retrieved, rather than
                                   stored in memory */

#define HASHTBLSIZE		2053	/* Size of hash table into the message
								   id list */

#define TIMEOUT			60 * 10	/* Max time to wait for a line from the
                                   server - 10 mins default. */

#define BATCHNAME		"nntp.XXXXXX"	/* Temporary filename for NNTP
										   batch */

/* END-OF-FILE */
